/**
  ******************************************************************************
  * @file    LCD_ctrl.c 
  * @author  Jakub Lanik
  * @version V1.0.0
  * @date    18.5.2012
  * @brief   Input_capture
  ******************************************************************************
  * @attention
  *
  *
  * <h2><center>&copy; COPYRIGHT </center></h2>
  ******************************************************************************  
  */ 


#include "LCD_ctrl.h"
#include "LCD_driver.h"
#include <stm32f4xx.h>
#include "stm32f4_discovery.h"
#include <stdio.h>
#include <stdlib.h>
#include  <string.h>


//global variables
char string[10];

// LCD initialisation procedure
void LCD_init(void)
{
GPIO_InitTypeDef GPIO_InitStructure;

//LCD_DDR = 0x0FF; misto teho
 RCC_AHB1PeriphClockCmd (RCC_AHB1Periph_GPIOE, ENABLE);

  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_UP ;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOE, &GPIO_InitStructure);

	LCD_CLR(LCD_RS);
	LCD_SET(LCD_E);
	LCD_home();
	LCD_CLR(LCD_E);
	delay(10000);
        //_delay_ms(10);
	LCD_SET(LCD_E);
	LCD_CLR(LCD_E);
        delay(200);
	//_delay_us(200);
	LCD_SET(LCD_E);
	LCD_CLR(LCD_E);
	delay(60);
		//platny data na tym portu se zapišo 3x po sobě kdyby to náhodo nechtělo vyjit

	LCD_wr_cmd(0x20);  //4bits, line display, 5x7 dots, asi tod musi byt kvuli temu aby se nastavily 4 bity a pak to šlape
	delay(60);
        LCD_wr_cmd(0x28);  //2 lines display
	LCD_clear();		//displej clear
	LCD_wr_cmd(0x08);  //display off , cursor off , brinking off , tohle by tod byt ani nemuselo
	delay(60);
        LCD_wr_cmd(0x0C);  //display on
	delay(60);
        LCD_wr_cmd(0x06);  //increment , not shifted
		//tohle se tak prostě musi naházet jinak to nejede sice nechápu proč to musim prvni nulovat a pak nastavovat....
}

// write string to LCD
void LCD_puts (char *c)
{
	unsigned char x=*c;
	while (x!=0)
	{
		LCD_wr_data(*c++);
		x=*c;
	}
}


// set X,Y cursor position
void LCD_xy(unsigned char x,unsigned char y)
{
	unsigned char adr;
	y=y<<6;
	adr=x+y;
	adr+=0b10000000;
	LCD_wr_cmd(adr);
}

//#ifdef LCD_CONVERSION_MODULE
// Load my characters to CGRAM
void LCD_cgram_load(void){

	unsigned char i,j,temp;
	for(i=0;i<6;i++){
		LCD_wr_cmd(0b01000000+(i<<3));

		switch(i){
			case 0: temp=0b00000000; break;
			case 1: temp=0b00010000; break;
			case 2: temp=0b00011000; break;
			case 3: temp=0b00011100; break;
			case 4: temp=0b00011110; break;
			case 5: temp=0b00011111; break;
		}

		for(j=0;j<8;j++){
			LCD_wr_data(temp);
		}
	}

	//char 6
	LCD_wr_cmd(0b01110000);

	LCD_wr_data(0b00000010);
	LCD_wr_data(0b00000101);
	LCD_wr_data(0b00000010);
	LCD_wr_data(0b00000000);
	LCD_wr_data(0b00000000);
	LCD_wr_data(0b00000000);
	LCD_wr_data(0b00000000);
	LCD_wr_data(0b00000000);

	LCD_wr_cmd(0x80); 	//switch to DDRAM
}

char * uchar2string(char data_in, unsigned char sign_in){
	char temp;
	char sign;

	if(data_in==0) {
		strcpy(string,"   0");
		return string;
	}

	if(data_in>0){
		if (sign_in) sign='+'; else sign=' ';
	} else {
		sign='-';
		data_in=-data_in;
	}

	*(string)=' ';
	temp=data_in/100;
	data_in-=100*temp;
	if(!temp) temp=' '-48;
	*(string+1)=temp+48;

	temp=data_in/10;
	data_in-=10*temp;
	if(!temp && (*(string+1)==' ')) temp=' '-48;
	*(string+2)=temp+48;

	*(string+3)=data_in+48;
	*(string+4)=0;

	if(string[2]==' '){
		string[2]=sign;
		return string;
	}

	if(string[1]==' '){
		string[1]=sign;
		return string;
	}
	string[0]=sign;
	return string;
}

void LCD_putnum(char data_in,unsigned char sign){
	LCD_puts(uchar2string(data_in,sign));
}

void LCD_putnum_left(char data_in,unsigned char sign){
	unsigned char i=0;

	uchar2string(data_in,sign);
	while (string[i] == ' ')
		i++;

	LCD_puts(i+string);
}

void LCD_putunsigned(char data){
	uint32_t temp;

	temp=data/10000;
	data-=10000*temp;
	*(string)=temp+48;

	temp=data/1000;
	data-=1000*temp;
	*(string+1)=temp+48;

	temp=data/100;
	data-=100*temp;
	*(string+2)=temp+48;

	temp=data/10;
	data-=10*temp;
	*(string+3)=temp+48;

	*(string+4)=data+48;
	*(string+5)=0;

	LCD_puts(string);
}

//convert input data to bargraph and print it
void LCD_bargraph(unsigned char data){
	unsigned char i,temp;

//	data/=2;

	i=data;
	i/=5;
	while(i--)
		LCD_wr_data(5);

	temp=i;
	i=data;
	i=i%5;

	LCD_wr_data(i);

	temp=13-temp;
	while(temp--)
		LCD_wr_data(0);

}

unsigned char LCD_log(unsigned char data_in) {
	unsigned char temp;

	if (data_in <7){
		temp=3*data_in;
	} else
	if (data_in < 21){
		temp=data_in + 12;
	}
	if (data_in > 20){
		temp=data_in/5 + 28;
	}

	return (temp);
}



//#endif

