/**
  ******************************************************************************
  * @file    SPI_7953.c
  * @author  Lukas Michalik
  * @version V1.0.0
  * @date    17.5.2012
  * @brief   Input_capture
  ******************************************************************************
  * @attention
  *
  *
  * <h2><center>&copy; COPYRIGHT </center></h2>
  ******************************************************************************
  */

#include "stm32f4xx.h"
#include "SPI_7953.h"

  void SPI_7953_Init(void)
{
  GPIO_InitTypeDef GPIO_InitStructure;
  SPI_InitTypeDef  SPI_InitStructure;

  /* Enable the SPI periph */
  RCC_APB2PeriphClockCmd(ADE7953_SPI_CLK, ENABLE);

  /* Enable SCK, MOSI and MISO GPIO clocks */
  RCC_AHB1PeriphClockCmd(ADE7953_SPI_SCK_GPIO_CLK | ADE7953_SPI_MISO_GPIO_CLK | ADE7953_SPI_MOSI_GPIO_CLK, ENABLE);

  /* Enable CS 7953 GPIO clock */
  RCC_AHB1PeriphClockCmd(ADE7953_SPI_CS_GPIO_CLK, ENABLE);

  /* Enable CS MEMS GPIO clock */
  RCC_AHB1PeriphClockCmd(ADE7953_SPI_CS_GPIO_CLK, ENABLE);

  /* Enable INT1 GPIO clock */
  //RCC_AHB1PeriphClockCmd(ADE7953_SPI_INT1_GPIO_CLK, ENABLE);

  /* Enable INT2 GPIO clock */
  //RCC_AHB1PeriphClockCmd(ADE7953_SPI_INT2_GPIO_CLK, ENABLE);

  GPIO_PinAFConfig(ADE7953_SPI_SCK_GPIO_PORT, ADE7953_SPI_SCK_SOURCE, ADE7953_SPI_SCK_AF);
  GPIO_PinAFConfig(ADE7953_SPI_MISO_GPIO_PORT, ADE7953_SPI_MISO_SOURCE, ADE7953_SPI_MISO_AF);
  GPIO_PinAFConfig(ADE7953_SPI_MOSI_GPIO_PORT, ADE7953_SPI_MOSI_SOURCE, ADE7953_SPI_MOSI_AF);

  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_PuPd  = GPIO_PuPd_DOWN;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;

  /* SPI SCK pin configuration */
  GPIO_InitStructure.GPIO_Pin = ADE7953_SPI_SCK_PIN;
  GPIO_Init(ADE7953_SPI_SCK_GPIO_PORT, &GPIO_InitStructure);

  /* SPI  MOSI pin configuration */
  GPIO_InitStructure.GPIO_Pin =  ADE7953_SPI_MOSI_PIN;
  GPIO_Init(ADE7953_SPI_MOSI_GPIO_PORT, &GPIO_InitStructure);

  /* SPI MISO pin configuration */
  GPIO_InitStructure.GPIO_Pin = ADE7953_SPI_MISO_PIN;
  GPIO_Init(ADE7953_SPI_MISO_GPIO_PORT, &GPIO_InitStructure);

  /* SPI configuration -------------------------------------------------------*/
  SPI_I2S_DeInit(ADE7953_SPI);
  SPI_InitStructure.SPI_Direction = SPI_Direction_2Lines_FullDuplex;
  SPI_InitStructure.SPI_DataSize = SPI_DataSize_16b;
  SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;
  SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge;
  SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
  SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_128;
  SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;
  SPI_InitStructure.SPI_CRCPolynomial = 7;
  SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
  SPI_Init(ADE7953_SPI, &SPI_InitStructure);

  /* Enable SPI1  */
  SPI_Cmd(ADE7953_SPI, ENABLE);

  /* Configure GPIO PIN for Lis Chip select */
  GPIO_InitStructure.GPIO_Pin = ADE7953_SPI_CS_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(ADE7953_SPI_CS_GPIO_PORT, &GPIO_InitStructure);

  /* Deselect ADE7953: Chip Select high */
  GPIO_SetBits(ADE7953_SPI_CS_GPIO_PORT, ADE7953_SPI_CS_PIN);


   /* Configure GPIO PIN for MEMS Chip select */
  GPIO_InitStructure.GPIO_Pin = LIS302DL_SPI_CS_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(LIS302DL_SPI_CS_GPIO_PORT, &GPIO_InitStructure);

  /* Deselect MEMS : Chip Select high */
  GPIO_SetBits(LIS302DL_SPI_CS_GPIO_PORT, ADE7953_SPI_CS_PIN);

}

/**
  * @brief  Sends a Byte through the SPI interface and return the Byte received
  *         from the SPI bus.
  * @param  Byte : Byte send.
  * @retval The received byte value
  */